SimpleEvidence
==============

.. currentmodule:: semra.struct

.. autoclass:: SimpleEvidence
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~SimpleEvidence.mapping_set_names
      ~SimpleEvidence.model_computed_fields
      ~SimpleEvidence.model_config
      ~SimpleEvidence.model_fields

   .. rubric:: Methods Summary

   .. autosummary::

      ~SimpleEvidence.get_confidence
      ~SimpleEvidence.key

   .. rubric:: Attributes Documentation

   .. autoattribute:: mapping_set_names
   .. autoattribute:: model_computed_fields
   .. autoattribute:: model_config
   .. autoattribute:: model_fields

   .. rubric:: Methods Documentation

   .. automethod:: get_confidence
   .. automethod:: key
